==> magento-module-custom-attribute-serializable-graph-ql-0.1.3.zip: Model/Resolver/Cart/SetCustomAttributesOnCart.php <==
<?php
/************************************************************************
 *
 * ADOBE CONFIDENTIAL
 * ___________________
 *
 * Copyright 2024 Adobe
 * All Rights Reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of Adobe and its suppliers, if any. The intellectual
 * and technical concepts contained herein are proprietary to Adobe
 * and its suppliers and are protected by all applicable intellectual
 * property laws, including trade secret and copyright laws.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Adobe.
 * ************************************************************************
 */
declare(strict_types=1);

namespace Magento\CustomAttributeSerializableGraphQl\Model\Resolver\Cart;

use Magento\CustomAttributeSerializableGraphQl\Model\Resolver\InputArgumentValidator;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Exception\GraphQlInputException;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;
use Magento\Quote\Api\CartRepositoryInterface;
use Magento\QuoteGraphQl\Model\Cart\GetCartForUser;
use Magento\Framework\GraphQl\Exception\GraphQlAuthorizationException;
use Magento\Framework\GraphQl\Exception\GraphQlNoSuchEntityException;
use Magento\Framework\Exception\NoSuchEntityException;

/**
 * Sets custom attributes on a cart
 */
class SetCustomAttributesOnCart implements ResolverInterface
{
    /**
     * @param GetCartForUser $getCartForUser
     * @param CartRepositoryInterface $cartRepository
     * @param InputArgumentValidator $inputArgumentValidator
     */
    public function __construct(
        private readonly GetCartForUser $getCartForUser,
        private readonly CartRepositoryInterface $cartRepository,
        private readonly InputArgumentValidator $inputArgumentValidator
    ) {
    }

    /**
     * Sets custom attributes on a cart
     *
     * @param Field $field
     * @param mixed $context
     * @param ResolveInfo $info
     * @param array|null $value
     * @param array|null $args
     * @return array
     * @throws GraphQlInputException
     * @throws GraphQlAuthorizationException
     * @throws GraphQlNoSuchEntityException
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function resolve(Field $field, $context, ResolveInfo $info, array $value = null, array $args = null)
    {
        $inputArgs = $args['input'];
        $this->inputArgumentValidator->validate($inputArgs, ['cart_id']);

        try {
            $storeId = (int)$context->getExtensionAttributes()->getStore()->getId();
            // Shopping Cart validation
            $cart = $this->getCartForUser->execute($inputArgs['cart_id'], $context->getUserId(), $storeId);

            $attrs = [];
            foreach ($inputArgs['custom_attributes'] as $attribute) {
                $attrs[$attribute['attribute_code']] = $attribute['value'];
            }
            $cart->setCustomAttributes($attrs);
            $this->cartRepository->save($cart);

            return [
                'cart' => [
                    'model' => $cart
                ],
            ];
        } catch (GraphQlNoSuchEntityException $e) {
            throw $e;
        } catch (NoSuchEntityException $e) {
            throw new GraphQlNoSuchEntityException(__('The cart can\'t be loaded.'));
        }
    }
}

==> magento-module-custom-attribute-serializable-graph-ql-0.1.5.zip: Model/Resolver/Cart/SetCustomAttributesOnCart.php <==
<?php
/************************************************************************
 *
 * ADOBE CONFIDENTIAL
 * ___________________
 *
 * Copyright 2024 Adobe
 * All Rights Reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of Adobe and its suppliers, if any. The intellectual
 * and technical concepts contained herein are proprietary to Adobe
 * and its suppliers and are protected by all applicable intellectual
 * property laws, including trade secret and copyright laws.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Adobe.
 * ************************************************************************
 */
declare(strict_types=1);

namespace Magento\CustomAttributeSerializableGraphQl\Model\Resolver\Cart;

use Magento\CustomAttributeSerializableGraphQl\Model\Resolver\InputArgumentValidator;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Exception\GraphQlInputException;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;
use Magento\Quote\Api\CartRepositoryInterface;
use Magento\QuoteGraphQl\Model\Cart\GetCartForUser;
use Magento\Framework\GraphQl\Exception\GraphQlAuthorizationException;
use Magento\Framework\GraphQl\Exception\GraphQlNoSuchEntityException;
use Magento\Framework\Exception\NoSuchEntityException;

/**
 * Sets custom attributes on a cart
 */
class SetCustomAttributesOnCart implements ResolverInterface
{
    /**
     * @param GetCartForUser $getCartForUser
     * @param CartRepositoryInterface $cartRepository
     * @param InputArgumentValidator $inputArgumentValidator
     */
    public function __construct(
        private readonly GetCartForUser $getCartForUser,
        private readonly CartRepositoryInterface $cartRepository,
        private readonly InputArgumentValidator $inputArgumentValidator
    ) {
    }

    /**
     * Sets custom attributes on a cart
     *
     * @param Field $field
     * @param mixed $context
     * @param ResolveInfo $info
     * @param array|null $value
     * @param array|null $args
     * @return array
     * @throws GraphQlInputException
     * @throws GraphQlAuthorizationException
     * @throws GraphQlNoSuchEntityException
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function resolve(Field $field, $context, ResolveInfo $info, ?array $value = null, ?array $args = null)
    {
        $inputArgs = $args['input'];
        $this->inputArgumentValidator->validate($inputArgs, ['cart_id']);

        try {
            $storeId = (int)$context->getExtensionAttributes()->getStore()->getId();
            // Shopping Cart validation
            $cart = $this->getCartForUser->execute($inputArgs['cart_id'], $context->getUserId(), $storeId);

            $attrs = [];
            foreach ($inputArgs['custom_attributes'] as $attribute) {
                $attrs[$attribute['attribute_code']] = $attribute['value'];
            }
            $cart->setCustomAttributes($attrs);
            $this->cartRepository->save($cart);

            return [
                'cart' => [
                    'model' => $cart
                ],
            ];
        } catch (GraphQlNoSuchEntityException $e) {
            throw $e;
        } catch (NoSuchEntityException $e) {
            throw new GraphQlNoSuchEntityException(__('The cart can\'t be loaded.'));
        }
    }
}
